@@ -58,6 +58,7 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-link.h"
 #include "nautilus-trash-monitor.h"
+#include "nautilus-file-utilities.h"
 
 typedef enum   TransferKind         TransferKind;
 typedef struct TransferInfo         TransferInfo;
@@ -416,6 +417,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 	char *to_path;
 	char *to_text;
 	char *progress_label_text;
+	const char *hostname;
 	const char *from_prefix;
 	const char *to_prefix;
 	GnomeVFSURI *uri;
@@ -430,8 +432,9 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 
 	if (from_uri != NULL) {
 		uri = gnome_vfs_uri_new (from_uri);
-		item = gnome_vfs_uri_extract_short_name (uri);
+		item = nautilus_get_uri_shortname_for_display (uri);
 		from_path = gnome_vfs_uri_extract_dirname (uri);
+		hostname = NULL;
 
 		/* remove the last '/' */
 		length = strlen (from_path);
@@ -439,12 +442,15 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			from_path [length - 1] = '\0';
 		}
 
-		if (g_str_has_prefix (from_uri, "file://")) {
-			from_text = from_path;
-		} else {
+		if (!gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		if (hostname) {
 			from_text = g_strdup_printf (_("%s on %s"),
-				from_path, gnome_vfs_uri_get_host_name (uri));
+				from_path, hostname);
 			g_free (from_path);
+		} else {
+			from_text = from_path;
 		}
 		
 		gnome_vfs_uri_unref (uri);
@@ -457,6 +463,7 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 	if (to_uri != NULL) {
 		uri = gnome_vfs_uri_new (to_uri);
 		to_path = gnome_vfs_uri_extract_dirname (uri);
+		hostname = NULL;
 
 		/* remove the last '/' */
 		length = strlen (to_path);
@@ -464,12 +471,15 @@ progress_dialog_set_to_from_item_text (NautilusFileOperationsProgress *dialog,
 			to_path [length - 1] = '\0';
 		}
 
-		if (g_str_has_prefix (to_uri, "file://")) {
-			to_text = to_path;
-		} else {
+		if (!gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		if (hostname) {
 			to_text = g_strdup_printf (_("%s on %s"),
-				to_path, gnome_vfs_uri_get_host_name (uri));
+				to_path, hostname);
 			g_free (to_path);
+		} else {
+			to_text = to_path;
 		}
 
 		gnome_vfs_uri_unref (uri);
@@ -1140,8 +1150,10 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 					   "to copy the item, rename it and try again.");
 		}
 		
-		eel_run_simple_dialog (parent_for_error_dialog (transfer_info), TRUE, GTK_MESSAGE_ERROR, primary_text, secondary_text,
-				       _("Unable to Replace File"), GTK_STOCK_OK, NULL, NULL);
+		eel_run_simple_dialog (parent_for_error_dialog (transfer_info),
+				       TRUE, GTK_MESSAGE_ERROR,
+				       primary_text, secondary_text,
+				       GTK_STOCK_OK, NULL);
 
 		g_free (primary_text);
 		g_free (formatted_name);
@@ -1183,7 +1195,6 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 			 GTK_MESSAGE_QUESTION, 
 			 text, 
 			 secondary_text, 
-			 _("Conflict While Copying"),
 			 _("_Skip"), _("_Replace"), NULL);
 		g_free (text);	 
 
@@ -1202,7 +1213,6 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 		result = eel_run_simple_dialog
 			(parent_for_error_dialog (transfer_info), TRUE, GTK_MESSAGE_QUESTION, text, 
 			 secondary_text, 
-			 _("Conflict While Copying"),
 			 _("S_kip All"), _("Replace _All"), _("_Skip"), _("_Replace"), NULL);
 		g_free (text);
 
@@ -2078,7 +2088,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 				 ? _("You cannot copy items into the trash.")
 				 : _("You cannot create links inside the trash."),
 				 _("Files and folders can only be moved into the trash."), 
-				 NULL,
 				 GTK_STOCK_OK, NULL);
 			result = GNOME_VFS_ERROR_NOT_PERMITTED;
 		}
@@ -2104,9 +2113,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 						 ? _("You cannot move this trash folder.")
 						 : _("You cannot copy this trash folder."),
 					 _("A trash folder is used for storing items moved to the trash."),
-					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0)
-						 ? _("Can't Change Trash Location")
-						 : _("Can't Copy Trash"),
 					 GTK_STOCK_OK, NULL, NULL);
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
@@ -2133,10 +2139,7 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 ? _("You cannot move a folder into itself.")
 					 : _("You cannot copy a folder into itself."), 
 					 _("The destination folder is inside the source folder."), 
-					 ((move_options & GNOME_VFS_XFER_REMOVESOURCE) != 0) 
-					 ? _("Can't Move Into Self")
-					 : _("Can't Copy Into Self"),
-					 GTK_STOCK_OK, NULL, NULL);			
+					 GTK_STOCK_OK, NULL, NULL);
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
 				break;
@@ -2150,7 +2153,6 @@ nautilus_file_operations_copy_move (const GList *item_uris,
 					 GTK_MESSAGE_ERROR,
 					 _("You cannot copy a file over itself."),
 					 _("The destination and source are the same file."), 
-					 _("Can't Copy Over Self"), 
 					 GTK_STOCK_OK, NULL, NULL);			
 
 				result = GNOME_VFS_ERROR_NOT_PERMITTED;
